public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
* [edk2-test] [PATCH 1/1] uefi-sct/SctPkg: fix typo 'Remained test cases'
@ 2019-09-03  9:52 Heinrich Schuchardt
  2019-09-04  2:27 ` Eric Jin
  0 siblings, 1 reply; 4+ messages in thread
From: Heinrich Schuchardt @ 2019-09-03  9:52 UTC (permalink / raw)
  To: devel; +Cc: Eric Jin, Supreeth Venkatesh, Stephano Cetola,
	Heinrich Schuchardt

%s/Remained/Remaining/g

Contributed-under: TianoCore Contribution Agreement 1.1
Signed-off-by: Heinrich Schuchardt <xypron.glpk@gmx.de>
---
 .../SctPkg/TestInfrastructure/SCT/Framework/Execute/Execute.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/uefi-sct/SctPkg/TestInfrastructure/SCT/Framework/Execute/Execute.c b/uefi-sct/SctPkg/TestInfrastructure/SCT/Framework/Execute/Execute.c
index 9e7f672e..6fd36914 100644
--- a/uefi-sct/SctPkg/TestInfrastructure/SCT/Framework/Execute/Execute.c
+++ b/uefi-sct/SctPkg/TestInfrastructure/SCT/Framework/Execute/Execute.c
@@ -608,10 +608,10 @@ Routine Description:
   //
   while (TRUE) {
     //
     // Calculate the number of remained cases
     //
     GetTestCaseRemainNum(&Remain);
-    SctPrint(L"  Remained test cases: %d\n", Remain);
+    SctPrint(L"  Remaining test cases: %d\n", Remain);
 
     //
     // Send assertion to remotion computer in passive mode to inform case begin.
@@ -608,10 +608,10 @@ Routine Description:
   while (TRUE) {
     //
-    // Calculate the number of remained cases
+    // Calculate the number of remaining test cases
     //
     GetTestCaseRemainNum(&Remain);
-- 
2.23.0.rc1


^ permalink raw reply related	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2019-09-06  3:54 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2019-09-03  9:52 [edk2-test] [PATCH 1/1] uefi-sct/SctPkg: fix typo 'Remained test cases' Heinrich Schuchardt
2019-09-04  2:27 ` Eric Jin
2019-09-04  6:37   ` Heinrich Schuchardt
2019-09-06  3:54     ` Eric Jin

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox